#!/bin/sh
usage() {
cat <<EOF
Usage: menulog [-stl] [-d YYYY-MM-DD] [-u userid] [-m|-M menu] [-o|-O option] [-p|-P program]
Desc: Print "MENU.LOG"
Options:
  -d only show records greater than date (YYYY-MM-DD)
  -s pull from "MENU.LOG.SUM"
  -t sort by timestamp
  -l only show last time and number of times option was used
  -m only show records for this menu (no wildcards)
  -M only show records for this menu (% and ? are wildcards)
  -o only show records for this option (no wildcards)
  -O only show records for this option (% and ? are wildcards)
  -p only show records for this option (no wildcards)
  -P only show records for this option (% and ? are wildcards)
  -u only show records for this userid
Examples:
  menulog -m %MNAW -o 1
  menulog -o PINE
EOF
}

scrn='%'
scrnlike=like
opt='%'
optlike=like
pgm='%'
pgmlike=like
order=""
order=""
user=""
when=""
dosum=N
dolist=N

test "$1" = '-?' && usage && exit 0

while test $# -gt 0
do
  case "$1" in
  -s) dosum=Y; shift;;
  -l) dolist=Y; shift;;
  -M) scrn="$2"; shift 2;;
  -m) scrn="$2"; scrnlike='='; shift 2;;
  -O) opt="$2"; shift 2;;
  -o) opt="$2"; optlike='='; shift 2;;
  -P) pgm="$2"; shift 2;;
  -p) pgm="$2"; pgmlike='='; shift 2;;
  -d) if test $dosum = N
      then when="and l.#3 > timestamp'$2'"
      else when="and s.#4 > timestamp'$2'"
      fi
      shift 2;;
  -u) if test $dosum = N
      then user="and l.#5 = $2"
      else user="and s.#3 = $2"
      fi
      shift 2;;
  -t) if test $dosum = N
      then order="order by l.#3,l.#4,l.#1,l.#2"
      else order="order by s.#4,s.#1,s.#2"
      fi
      shift;;
  *) echo "Invalid option: $1" ; exit 1;; 
  esac
done

BTASDIR=/edx
export BTASDIR

if test $dolist = Y
then
case "$dosum" in
Y) select='#1 "MENU",#2 "OPTION",max(#4) "LAST TIME",sum(#5) "COUNT"'
   from='"MENU.LOG.SUM"'
   ;;
*) select='#1 "MENU",#2 "OPTION",max(#3) "LAST TIME",count(1) "COUNT"'
   from='"MENU.LOG"'
   ;;
esac
sql -u <<EOF
select $select
from $from
where #1 $scrnlike '$scrn'
and #2 $optlike '$opt'
group by #1,#2
;
EOF
exit
fi

if test $dosum = Y
then sql -u <<EOF
select s.#1 "MENU",s.#2 "OPTION",f.#3 "PROGRAM",f.#4 "VOLUME",
pic(s.#3,'ZZZZ') "UID",substring(u.#4 for 20) "USER",
timemask(s.#4,'YYYY-MM-DD hh:mm:ss') "LAST TIME",pic(s.#5,'ZZZZZ#') "COUNT"
from "MENU.LOG.SUM" s, "MENU.FILE" f,"MENU.USER" u
where s.#1 $scrnlike '$scrn'
and s.#2 $optlike '$opt'
and f.#1 = s.#1
and f.#2 = s.#2
and f.#3 $pgmlike '$pgm'
$user
$when
and u.#1 = s.#3
$order
$group
;
EOF
#else cat <<EOF
else sql -u <<EOF
select l.#1 "MENU",l.#2 "OPTION",f.#3 "PROGRAM",f.#4 "VOLUME",
pic(l.#5,'ZZZZ') "UID",substring(u.#4 for 16) "USER",
timemask(l.#3,'YYYY-MM-DD hh:mm:ss') "TIME"
from "MENU.LOG" l, "MENU.FILE" f,"MENU.USER" u
where l.#1 $scrnlike '$scrn'
and l.#2 $optlike '$opt'
and f.#1 = l.#1
and f.#2 = l.#2
and f.#3 $pgmlike '$pgm'
$user
$when
and u.#1 = l.#5
$order
$group
;
EOF
fi
