#!/bin/sh
usage() {
cat <<EOF
Usage: menusum.sh [-d days]
Options: -d days Number of days to keep.
Description:
  Keep running summary of /edx/MENU.LOG in /edx/MENU.LOG.SUM.
  Deletes records more than x days (default 5) old from MENU.LOG.
Example:
  menusum.sh -d 14
EOF
}

BTASDIR=/edx
MONEY=NEW
export BTASDIR MONEY

LOG=/usr/tmp/menusum.log
exec >>$LOG 2>&1
echo Started `date '+%F %T'` `id -u` `id -u -n` $*

days=5

while test $# -gt 0
do case "$1" in
-d) shift; days="$1"; shift;;
*) usage; exit 1;;
esac
done

daysago=$(date -d "$days days ago" '+%Y-%m-%d')

/bms/bin/sql -u <<EOF
// Delete records in temporary summary file.
delete from "MENU.LOG.LAST"
where #1 != ''
;

// Summarize current MENU.LOG file.
insert into "MENU.LOG.LAST"
select #1,#2,#5,MAX(#3),count(#5) from "MENU.LOG"
group by #1,#2,#5
;

// Insert records from old summary.
insert into "MENU.LOG.LAST"
select * from "MENU.LOG.SUM"
;

// Delete old summary records.
delete from "MENU.LOG.SUM"
where #1 != ''
;

// Create new summary records.
insert into "MENU.LOG.SUM"
select #1,#2,#3,MAX(#4),SUM(#5)
from "MENU.LOG.LAST"
group by #1,#2,#3
;

// Delete menu log records.
delete from "MENU.LOG"
where #3 < timestamp'$daysago'
;

EOF
echo Started `date '+%F %T'`
