#!/bin/sh
usage() {
cat <<EOF
Usage: pgmlog [-stl] [-d YYYY-MM-DD] [-e|-E edxterm] [-p|-P program]
Desc: Print "PGM.LOG" for today's date.
Options:
  -a show all records (not just today's)
  -s pull from "PGM.LOG.SUM"
  -t sort by timestamp
  -l only show last time and number of times program was used
  -d only show records equal to date (YYYY-MM-DD)
  -e only show records for this edxterm (no wildcards)
  -E only show records for this edxterm (% and ? are wildcards)
  -p only show records for this program (no wildcards)
  -P only show records for this program (% and ? are wildcards)
Examples:
  menulog -e IMP109
  menulog -e IMP109 -p CBINED
  menulog -P CBIN%
EOF
}

edx='%'
edxlike=like
pgm='%'
pgmlike=like
when=""
order=""
group=""
dosum=N
dolist=N
doall=N

pgmtime="(#1+1900)*10000000000+#2*100000000+#3*1000000+#4*10000+#5*100+#6"
timepic="'####-##-## ##:##:##'"
countpic="'ZZZZ#'"

test "$1" = '-?' && usage && exit 0

yr=$(date +%Y)
mn=$(date +%m)
dy=$(date +%d)
when="and (l.#1+1900) = $yr and l.#2 = $mn and l.#3 = $dy"

while test $# -gt 0
do
  case "$1" in
  -a) when=''; doall=Y; shift;;
  -s) dosum=Y;
      if test $doall != Y
      then
	# Note: we set when to today's date but there is unlikely to be
	# data in the summary file for today.
	dayone=$(date -d "today" '+%Y%m%d')
	daytwo=$(date -d "tomorrow" '+%Y%m%d')
	when="and s.#3 > ${dayone}000000 and s.#3 < ${daytwo}000000"
      fi
      shift;;
  -l) dolist=Y; shift;;
  -E) edx="$2"; shift 2;;
  -e) edx="$2"; edxlike='='; shift 2;;
  -P) pgm="$2"; shift 2;;
  -p) pgm="$2"; pgmlike='='; shift 2;;
  -d) # Assume $2 (date) is YYYY-MM-DD
      yr=${2%??????}	# extract first four characters (YYYY)
      mndy=${2#?????} # extract last five characters (MM-DD)
      mn=${mndy%???}	# extract first 2 characters from mndy (MM)
      dy=${mndy#???}	# extract last 2 characters from mndy (DD)
      if test $dosum = N
      then 
        when="and (l.#1+1900) = $yr and l.#2 = $mn and l.#3 = $dy"
      else
	dayone=$(date -d "$2" '+%Y%m%d')
	daytwo=$(date -d "$2 + 1 day" '+%Y%m%d')
        when="and s.#3 > ${dayone}000000 and s.#3 < ${daytwo}000000"
      fi
      shift 2;;
  -t) if test $dosum = N
      then order="order by l.#3,l.#4,l.#1,l.#2"
      else order="order by s.#3,s.#1,s.#2"
      fi
      shift;;
  *) echo "Invalid option: $1" ; exit 1;; 
  esac
done

BTASDIR=/edx
export BTASDIR

if test $dolist = Y
then
case "$dosum" in
Y) select='#1 "TERM",#2 "PROGRAM",
pic(max(#3),'"$timepic"') "LAST TIME",
pic(sum(#4),'"$countpic"') "COUNT"'
   from='"PGM.LOG.SUM"'
   ;;
*) select='#7 "TERM",#8 "PROGRAM",max('$pgmtime') "LAST TIME"'
   from='"PGM.LOG"'
   ;;
esac
sql -u <<EOF
select $select
from $from
where #1 $edxlike '$edx'
and #2 $pgmlike '$pgm'
group by #1,#2
;
EOF
exit
fi

if test $dosum = Y
then sql -u <<EOF
select s.#1 "TERM",s.#2 "PROGRAM",
pic(s.#3,'####-##-##-##:##:##') "LAST TIME",pic(s.#4,'ZZZZZ#') "COUNT"
from "PGM.LOG.SUM" s
where s.#1 $edxlike '$edx'
and s.#2 $pgmlike '$pgm'
$when
$order
$group
;
EOF
else sql -u <<EOF
select l.#7 "TERM",l.#8 "PROGRAM",
pic($pgmtime,'####-##-##-##:##:##') "TIME"
from "PGM.LOG" l
where l.#7 $edxlike '$edx'
and l.#8 $pgmlike '$pgm'
$when
$order
$group
;
EOF
fi
