#!/bin/sh
usage() {
cat <<EOF
Usage: pgmsum.sh [-d days]
Options: -d days Number of days to keep.
Description:
  Keep running summary of /edx/PGM.LOG in /edx/PGM.LOG.SUM.
  Deletes records more than x days (default 5) old from PGM.LOG.
Example:
  pgmsum.sh -d 14
EOF
}

BTASDIR=/edx
MONEY=NEW
export BTASDIR MONEY

#/bms/bin/sql -u <<EOF
#select #7,#8,
#MAX((#1+1900)*10000000000+#2*100000000+#3*1000000+#4*10000+#5*100+#6),count(#8)
#from "PGM.LOG"
#group by #7,#8
#;
#EOF
#
#exit

LOG=/usr/tmp/pgmsum.log
exec >>$LOG 2>&1
echo Started `date '+%F %T'` `id` $*

days=5

while test $# -gt 0
do case "$1" in
-d) shift; days="$1"; shift;;
*) usage; exit 1;;
esac
done

today=$(date -d "$days days ago" '+%m%d%Y')
month=${today:0:2}
day=${today:2:2}
year=${today:4:4}

creatework() {
# Create workfiles
/bms/bin/btutil 'de PGM.LOG.YMD'
/bms/bin/btutil 'de PGM.LOG.LAST'
/bms/bin/btutil 'cr PGM.LOG.YMD 3 c 8 c 8 n0 6 .'	# normalize mdyhms
/bms/bin/btutil 'cr PGM.LOG.LAST 4 c 8 c 8 n0 6 n0 4 .'	# key includes count

# Create summary file, if it doesn't exist yet.
if /bms/bin/btutil 'di PGM.LOG.SUM' 2>&1 | egrep 'not found'
then
  # Note: key for summary file doesn't include count
  /bms/bin/btutil 'cr PGM.LOG.SUM 3 c 8 c 8 n0 6 n0 4 .'
fi
}

copylog2ymd() {
echo Copy records from PGM.LOG to PGM.LOG.YMD
/bms/bin/sql -u <<EOF
insert into "PGM.LOG.YMD"
select #7,#8,(#1+1900)*10000000000+#2*100000000+#3*1000000+#4*10000+#5*100+#6
from "PGM.LOG"
where #1 < ($year - 1900)
or (#1 <= ($year - 1900) and #2 < $month)
or (#1 <= ($year - 1900) and #2 <= $month and #3 < $day)
;
EOF
}

copyymd2last() {
echo Create summary of records from PGM.LOG.YMD to PGM.LOG.LAST
/bms/bin/sql -u <<EOF
insert into "PGM.LOG.LAST"
select #1,#2,MAX(#3),count(#2)
from "PGM.LOG.YMD"
group by #1,#2
;
EOF
}

copysum2last() {
echo Insert records from PGM.LOG.SUM to PGM.LOG.LAST
/bms/bin/sql -u <<EOF
insert into "PGM.LOG.LAST"
select * from "PGM.LOG.SUM"
;
EOF
}

purgesum() {
echo Delete old summary records from PGM.LOG.SUM
/bms/bin/sql -u <<EOF
delete from "PGM.LOG.SUM"
where #1 != ''
;
EOF
}

copylast2sum() {
echo Create new PGM.LOG.SUM from PGM.LOG.LAST
/bms/bin/sql -u <<EOF
insert into "PGM.LOG.SUM"
select #1,#2,MAX(#3),SUM(#4)
from "PGM.LOG.LAST"
group by #1,#2
;
EOF
}

purgelog() {
echo Delete log records from PGM.LOG
/bms/bin/sql -u <<EOF
delete from "PGM.LOG"
where #1 < ($year - 1900)
or (#1 <= ($year - 1900) and #2 < $month)
or (#1 <= ($year - 1900) and #2 <= $month and #3 < $day)
;
EOF
}

creatework
copylog2ymd
copyymd2last
copysum2last
purgesum
copylast2sum
purgelog

echo Finished `date '+%F %T'`
